pynspect
================================================================================

Python 3 library for filtering, querying or inspecting almost arbitrary data
structures.

This README file is work in progress, for more information please consult source
code and unit tests.
